@@ -263,10 +263,12 @@ char * type2text(int type)
 */
 void kerneld_error (const char *ctl, ...)
 {
-	char buf[1000];
+	char buf[1024];
 	va_list list;
+
 	va_start (list,ctl);
-	vsprintf (buf,ctl,list);
+	vsnprintf (buf, sizeof buf, ctl, list);
+	va_end (list);
 	syslog (LOG_ERR,"%s",buf);
 }
 
